@@ -3,7 +3,7 @@ package Net::DNS::Domain;
 use strict;
 use warnings;
 
-our $VERSION = (qw$Id: Domain.pm 1894 2023-01-12 10:59:08Z willem $)[2];
+our $VERSION = (qw$Id: Domain.pm 1911 2023-04-17 12:30:59Z willem $)[2];
 
 
 =head1 NAME
@@ -171,17 +171,14 @@ sub name {
 
 =head2 fqdn
 
-    @fqdn = $domain->fqdn;
+    $fqdn = $domain->fqdn;
 
 Returns a character string containing the fully qualified domain
 name, including the trailing dot.
 
 =cut
 
-sub fqdn {
-	my $name = &name;
-	return $name =~ /[.]$/ ? $name : $name . '.';		# append trailing dot
-}
+sub fqdn { return $name =~ /[.]$/ ? $name : "$name." }		# append trailing dot
 
 
 =head2 xname
@@ -244,10 +241,7 @@ represented by the appropriate escape sequence.
 
 =cut
 
-sub string {
-	my $name = &name;
-	return $name =~ /[.]$/ ? $name : $name . '.';		# append trailing dot
-}
+sub string { return &fqdn }
 
 
 =head2 origin
@@ -266,7 +260,7 @@ my $placebo = sub { my $constructor = shift; &$constructor; };
 
 sub origin {
 	my ( $class, $name ) = @_;
-	my $domain = defined $name ? Net::DNS::Domain->new($name) : return $placebo;
+	my $domain = defined $name ? __PACKAGE__->new($name) : return $placebo;
 
 	return sub {						# closure w.r.t. $domain
 		my $constructor = shift;
